==> golang-github-ionos-cloud-sdk-go_6.1.4.orig.tar.gz: golang-github-ionos-cloud-sdk-go-6.1.4/docs/models/KubernetesClusterForPost.md <==
# KubernetesClusterForPost

## Properties

|Name | Type | Description | Notes|
|------------ | ------------- | ------------- | -------------|
|**Id** | Pointer to **string** | The resource&#39;s unique identifier. | [optional] [readonly] |
|**Type** | Pointer to **string** | The type of object. | [optional] [readonly] |
|**Href** | Pointer to **string** | URL to the object representation (absolute path). | [optional] [readonly] |
|**Metadata** | Pointer to [**DatacenterElementMetadata**](DatacenterElementMetadata.md) |  | [optional] |
|**Properties** | [**KubernetesClusterPropertiesForPost**](KubernetesClusterPropertiesForPost.md) |  | |
|**Entities** | Pointer to [**KubernetesClusterEntities**](KubernetesClusterEntities.md) |  | [optional] |

## Methods

### NewKubernetesClusterForPost

`func NewKubernetesClusterForPost(properties KubernetesClusterPropertiesForPost, ) *KubernetesClusterForPost`

NewKubernetesClusterForPost instantiates a new KubernetesClusterForPost object
This constructor will assign default values to properties that have it defined,
and makes sure properties required by API are set, but the set of arguments
will change when the set of required properties is changed

### NewKubernetesClusterForPostWithDefaults

`func NewKubernetesClusterForPostWithDefaults() *KubernetesClusterForPost`

NewKubernetesClusterForPostWithDefaults instantiates a new KubernetesClusterForPost object
This constructor will only assign default values to properties that have it defined,
but it doesn't guarantee that properties required by API are set

### GetId

`func (o *KubernetesClusterForPost) GetId() string`

GetId returns the Id field if non-nil, zero value otherwise.

### GetIdOk

`func (o *KubernetesClusterForPost) GetIdOk() (*string, bool)`

GetIdOk returns a tuple with the Id field if it's non-nil, zero value otherwise
and a boolean to check if the value has been set.

### SetId

`func (o *KubernetesClusterForPost) SetId(v string)`

SetId sets Id field to given value.

### HasId

`func (o *KubernetesClusterForPost) HasId() bool`

HasId returns a boolean if a field has been set.

### GetType

`func (o *KubernetesClusterForPost) GetType() string`

GetType returns the Type field if non-nil, zero value otherwise.

### GetTypeOk

`func (o *KubernetesClusterForPost) GetTypeOk() (*string, bool)`

GetTypeOk returns a tuple with the Type field if it's non-nil, zero value otherwise
and a boolean to check if the value has been set.

### SetType

`func (o *KubernetesClusterForPost) SetType(v string)`

SetType sets Type field to given value.

### HasType

`func (o *KubernetesClusterForPost) HasType() bool`

HasType returns a boolean if a field has been set.

### GetHref

`func (o *KubernetesClusterForPost) GetHref() string`

GetHref returns the Href field if non-nil, zero value otherwise.

### GetHrefOk

`func (o *KubernetesClusterForPost) GetHrefOk() (*string, bool)`

GetHrefOk returns a tuple with the Href field if it's non-nil, zero value otherwise
and a boolean to check if the value has been set.

### SetHref

`func (o *KubernetesClusterForPost) SetHref(v string)`

SetHref sets Href field to given value.

### HasHref

`func (o *KubernetesClusterForPost) HasHref() bool`

HasHref returns a boolean if a field has been set.

### GetMetadata

`func (o *KubernetesClusterForPost) GetMetadata() DatacenterElementMetadata`

GetMetadata returns the Metadata field if non-nil, zero value otherwise.

### GetMetadataOk

`func (o *KubernetesClusterForPost) GetMetadataOk() (*DatacenterElementMetadata, bool)`

GetMetadataOk returns a tuple with the Metadata field if it's non-nil, zero value otherwise
and a boolean to check if the value has been set.

### SetMetadata

`func (o *KubernetesClusterForPost) SetMetadata(v DatacenterElementMetadata)`

SetMetadata sets Metadata field to given value.

### HasMetadata

`func (o *KubernetesClusterForPost) HasMetadata() bool`

HasMetadata returns a boolean if a field has been set.

### GetProperties

`func (o *KubernetesClusterForPost) GetProperties() KubernetesClusterPropertiesForPost`

GetProperties returns the Properties field if non-nil, zero value otherwise.

### GetPropertiesOk

`func (o *KubernetesClusterForPost) GetPropertiesOk() (*KubernetesClusterPropertiesForPost, bool)`

GetPropertiesOk returns a tuple with the Properties field if it's non-nil, zero value otherwise
and a boolean to check if the value has been set.

### SetProperties

`func (o *KubernetesClusterForPost) SetProperties(v KubernetesClusterPropertiesForPost)`

SetProperties sets Properties field to given value.


### GetEntities

`func (o *KubernetesClusterForPost) GetEntities() KubernetesClusterEntities`

GetEntities returns the Entities field if non-nil, zero value otherwise.

### GetEntitiesOk

`func (o *KubernetesClusterForPost) GetEntitiesOk() (*KubernetesClusterEntities, bool)`

GetEntitiesOk returns a tuple with the Entities field if it's non-nil, zero value otherwise
and a boolean to check if the value has been set.

### SetEntities

`func (o *KubernetesClusterForPost) SetEntities(v KubernetesClusterEntities)`

SetEntities sets Entities field to given value.

### HasEntities

`func (o *KubernetesClusterForPost) HasEntities() bool`

HasEntities returns a boolean if a field has been set.

==> golang-github-ionos-cloud-sdk-go_6.1.11.orig.tar.gz: golang-github-ionos-cloud-sdk-go-6.1.11/docs/models/KubernetesClusterForPost.md <==
# KubernetesClusterForPost

## Properties

|Name | Type | Description | Notes|
|------------ | ------------- | ------------- | -------------|
|**Entities** | Pointer to [**KubernetesClusterEntities**](KubernetesClusterEntities.md) |  | [optional] |
|**Href** | Pointer to **string** | The URL to the object representation (absolute path). | [optional] [readonly] |
|**Id** | Pointer to **string** | The resource unique identifier. | [optional] [readonly] |
|**Metadata** | Pointer to [**DatacenterElementMetadata**](DatacenterElementMetadata.md) |  | [optional] |
|**Properties** | [**KubernetesClusterPropertiesForPost**](KubernetesClusterPropertiesForPost.md) |  | |
|**Type** | Pointer to **string** | The object type. | [optional] [readonly] |

## Methods

### NewKubernetesClusterForPost

`func NewKubernetesClusterForPost(properties KubernetesClusterPropertiesForPost, ) *KubernetesClusterForPost`

NewKubernetesClusterForPost instantiates a new KubernetesClusterForPost object
This constructor will assign default values to properties that have it defined,
and makes sure properties required by API are set, but the set of arguments
will change when the set of required properties is changed

### NewKubernetesClusterForPostWithDefaults

`func NewKubernetesClusterForPostWithDefaults() *KubernetesClusterForPost`

NewKubernetesClusterForPostWithDefaults instantiates a new KubernetesClusterForPost object
This constructor will only assign default values to properties that have it defined,
but it doesn't guarantee that properties required by API are set

### GetEntities

`func (o *KubernetesClusterForPost) GetEntities() KubernetesClusterEntities`

GetEntities returns the Entities field if non-nil, zero value otherwise.

### GetEntitiesOk

`func (o *KubernetesClusterForPost) GetEntitiesOk() (*KubernetesClusterEntities, bool)`

GetEntitiesOk returns a tuple with the Entities field if it's non-nil, zero value otherwise
and a boolean to check if the value has been set.

### SetEntities

`func (o *KubernetesClusterForPost) SetEntities(v KubernetesClusterEntities)`

SetEntities sets Entities field to given value.

### HasEntities

`func (o *KubernetesClusterForPost) HasEntities() bool`

HasEntities returns a boolean if a field has been set.

### GetHref

`func (o *KubernetesClusterForPost) GetHref() string`

GetHref returns the Href field if non-nil, zero value otherwise.

### GetHrefOk

`func (o *KubernetesClusterForPost) GetHrefOk() (*string, bool)`

GetHrefOk returns a tuple with the Href field if it's non-nil, zero value otherwise
and a boolean to check if the value has been set.

### SetHref

`func (o *KubernetesClusterForPost) SetHref(v string)`

SetHref sets Href field to given value.

### HasHref

`func (o *KubernetesClusterForPost) HasHref() bool`

HasHref returns a boolean if a field has been set.

### GetId

`func (o *KubernetesClusterForPost) GetId() string`

GetId returns the Id field if non-nil, zero value otherwise.

### GetIdOk

`func (o *KubernetesClusterForPost) GetIdOk() (*string, bool)`

GetIdOk returns a tuple with the Id field if it's non-nil, zero value otherwise
and a boolean to check if the value has been set.

### SetId

`func (o *KubernetesClusterForPost) SetId(v string)`

SetId sets Id field to given value.

### HasId

`func (o *KubernetesClusterForPost) HasId() bool`

HasId returns a boolean if a field has been set.

### GetMetadata

`func (o *KubernetesClusterForPost) GetMetadata() DatacenterElementMetadata`

GetMetadata returns the Metadata field if non-nil, zero value otherwise.

### GetMetadataOk

`func (o *KubernetesClusterForPost) GetMetadataOk() (*DatacenterElementMetadata, bool)`

GetMetadataOk returns a tuple with the Metadata field if it's non-nil, zero value otherwise
and a boolean to check if the value has been set.

### SetMetadata

`func (o *KubernetesClusterForPost) SetMetadata(v DatacenterElementMetadata)`

SetMetadata sets Metadata field to given value.

### HasMetadata

`func (o *KubernetesClusterForPost) HasMetadata() bool`

HasMetadata returns a boolean if a field has been set.

### GetProperties

`func (o *KubernetesClusterForPost) GetProperties() KubernetesClusterPropertiesForPost`

GetProperties returns the Properties field if non-nil, zero value otherwise.

### GetPropertiesOk

`func (o *KubernetesClusterForPost) GetPropertiesOk() (*KubernetesClusterPropertiesForPost, bool)`

GetPropertiesOk returns a tuple with the Properties field if it's non-nil, zero value otherwise
and a boolean to check if the value has been set.

### SetProperties

`func (o *KubernetesClusterForPost) SetProperties(v KubernetesClusterPropertiesForPost)`

SetProperties sets Properties field to given value.


### GetType

`func (o *KubernetesClusterForPost) GetType() string`

GetType returns the Type field if non-nil, zero value otherwise.

### GetTypeOk

`func (o *KubernetesClusterForPost) GetTypeOk() (*string, bool)`

GetTypeOk returns a tuple with the Type field if it's non-nil, zero value otherwise
and a boolean to check if the value has been set.

### SetType

`func (o *KubernetesClusterForPost) SetType(v string)`

SetType sets Type field to given value.

### HasType

`func (o *KubernetesClusterForPost) HasType() bool`

HasType returns a boolean if a field has been set.
